# zipp

##### this is a .zip file aggregate

## Installation

```shell
pip install zipp
```



```python
import zipp

# backup2zip
zipp.backup2zip(floder=, backupfilename=)

# decompression
zipp.decompression(name=)
```
